import json

from django.http import HttpResponse
from rest_framework import response
from rest_framework.views import APIView
from django.core.cache import cache

from ..services.user_service import UserService
from ..services.user_login_register import LoginRegister
from ..utils.custom_response import util_response

class ShortMessageLogin(APIView):
    # 短信验证码校验
    def post(self, request):
        # 1. 电话和手动输入的验证码
        phone = request.POST.get('phone')
        code = request.POST.get('code')
        if code is None:
            res = {
                'err': 4002,
                'msg': '验证码不能为空',
            }
            return response.Response(data=res, status=None, template_name=None)
        # 2. 获取redis中保存的code
        # print('缓存中是否包含:', cache.has_key(phone))
        # print('取值:', cache.get(phone))
        cache_code = cache.get(phone)
        # 3. 判断
        account, error = UserService.check_account(phone)
        # print("账户：", account)
        if code == cache_code:
            err, data = LoginRegister.login_register(phone)
            if err == 0:
                return util_response(data=data)
            else:
                return util_response(msg=err, err=6004)
        else:
            res = {
                'err': 4002,
                'msg': '验证码错误',
            }
            return response.Response(data=res, status=None, template_name=None)


class MyApiError(Exception):
    def __init__(self, message, err_code=4010):
        self.msg = message
        self.err = err_code

    def __str__(self):
        # repr()将对象转化为供解释器读取的形式。可省略
        return repr(self.msg)



import json

from django.core import serializers

from ..models import Group, BaseInfo

tree = []
index = 0


class UserGroupTreeService():
    @staticmethod
    def tree_loop(parent_group=0, level=1):
        first_level = Group.objects.filter(parent_group=parent_group).to_json()
        if not first_level:
            return []
        for j in first_level:
            j['children'] = UserGroupTreeService.tree_loop(j['id'])
        return first_level

    def parse_model(res_set, need_all=False):
        json_data = json.loads(serializers.serialize('json', res_set))
        if not json_data:
            return None
        else:
            if not need_all:
                return json_data[0]['fields']
            else:
                return [i['fields'] for i in json_data]

    @staticmethod
    def getTree(list, parent_group):
        tree = []
        for item in list:
            if item['parent_group'] == str(parent_group):
                item['children'] = UserGroupTreeService.getTree(list, item['id'])
                tree.append(item)

        return tree

    @staticmethod
    def getTrees(list, parent_group):
        tree = []
        if parent_group != 0:
            a = UserGroupTreeService.grop(parent_group)
            print(a)
            for item in list:
                if item['parent_group'] == str(parent_group):
                    item['children'] = UserGroupTreeService.getTree(list, item['id'])
                    tree.append(item)
            a[0]['children'] = tree
            return a[0]
        else:
            for item in list:
                if item['parent_group'] == str(parent_group):
                    item['children'] = UserGroupTreeService.getTree(list, item['id'])
                    tree.append(item)

        return tree

    @staticmethod
    def grop(id):
        gruop = Group.objects.filter(id=id).to_json()
        return gruop

    @staticmethod
    def group_tree(user_id):
        user_group_id = BaseInfo.objects.filter(id=user_id).first().to_json()
        # print(user_group_id['user_group_id'])
        first_level = Group.objects.filter().to_json()
        group_tree = UserGroupTreeService.getTrees(first_level, user_group_id['user_group_id'])
        return group_tree, None



from rest_framework.views import APIView
from ..services.user_service import UserService
from ..services.user_group_tree_service import UserGroupTreeService
from ..utils.custom_response import util_response
from ..utils.model_handle import parse_data


class UserGroupTree(APIView):
    # 在有的框架中会出现传入3个参数的问题，原因不明，可能和两边使用的版本不同有关
    def get(self, request, *args):
        token = request.META.get('HTTP_AUTHORIZATION', None)
        token_serv, error_text = UserService.check_token(token)
        if error_text:
            return util_response(err=6045, msg=error_text)
        data, error_text = UserGroupTreeService.group_tree(token_serv['user_id'])
        if not error_text:
            return util_response(data=data)
        return util_response(err=47767, msg=error_text)



from django.db.models import F
from rest_framework.response import Response

from xj_user.models import ContactBook
from xj_user.utils.custom_response import util_response


class ContactBookService:
    def get_list(self, user_id):
        user_contact_book_list = ContactBook.objects.annotate(user_name=F('friend__user_name'), ).filter(
            user_id=user_id).values("id", "friend_id", "user_name")
        return Response({
            'err': 0,
            'msg': 'OK',
            'data': user_contact_book_list
        })

    def add_friends(self, data):
        friend = ContactBook.objects.filter(user_id=data['user_id'],friend_id=data['friend_id']).first()
        if friend:
            return util_response(data=[], msg='对方已经是你好友')
        user_contact_book = ContactBook.objects.create(**data)
        return Response({
            'err': 0,
            'msg': '添加好友成功',
            'data': {
                "contact_book_id": user_contact_book.id,
                # "token": token,
            }})



# encoding: utf-8
"""
@project: djangoModel->custom_tool
@author: 孙楷炎
@Email: sky4834@163.com
@synopsis: 自定义工具类
@created_time: 2022/9/5 13:57
"""


def is_number(s):
    """识别任何语言的数字字符串"""
    try:
        float(s)
        return True
    except ValueError:
        pass

    try:
        import unicodedata
        unicodedata.numeric(s)
        return True
    except (TypeError, ValueError):
        pass

    return False
